==> style-o-matic-1.1.5.tgz: package/es/components/Nav/NavItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, setCorePropDefaults, setCorePropTypes, getValidProps, ROLE } from "../../lib";

var NavItem = (_temp = _class = function (_CoreComponent) {
  _inherits(NavItem, _CoreComponent);

  function NavItem() {
    _classCallCheck(this, NavItem);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  NavItem.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uirole = _getValidProps.uirole,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        minimized = _getValidProps.minimized,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var classes = {
      active: to && path.indexOf(to) !== -1,
      minimized: minimized
    };

    if (uirole === ROLE.FOLDERITEM) {
      return React.createElement(
        Component,
        _extends({}, props, { className: classNames(className, classes) }),
        React.createElement(
          "a",
          { className: "ui-nav-item-link", href: to, label: text },
          React.createElement(
            "span",
            { className: "ui-nav-" + uirole + "-info" },
            text
          ),
          React.createElement("span", { className: "ui-nav-" + uirole + "-icon " + icon }),
          children
        )
      );
    }
    return React.createElement(
      Component,
      _extends({}, props, { className: classNames(className, classes) }),
      React.createElement(
        "a",
        { className: "ui-nav-item-link", href: to, label: text },
        React.createElement("span", { className: "ui-nav-" + uirole + "-icon " + icon }),
        React.createElement(
          "span",
          { className: "ui-nav-" + uirole + "-info" },
          text
        ),
        children
      )
    );
  };

  return NavItem;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "div",
  uirole: ROLE.ITEM,
  text: "",
  minimized: false
}), _temp);


export default NavItem;

==> style-o-matic-1.1.37.tgz: package/es/components/Nav/NavItem.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import classNames from "classnames";
import { CoreComponent, getCorePropDefaults, getCorePropTypes, getValidProps, ROLE } from "../../lib";

var NavItem = (_temp = _class = function (_CoreComponent) {
  _inherits(NavItem, _CoreComponent);

  function NavItem() {
    _classCallCheck(this, NavItem);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  NavItem.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        minimized = _getValidProps.minimized,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var classes = {
      active: to && path.indexOf(to) !== -1,
      minimized: minimized
    };

    return React.createElement(
      Component,
      _extends({}, props, {
        className: classNames(className, classes),
        href: to,
        label: text
      }),
      React.createElement("span", { className: "ui-" + uiclass + "-icon " + icon }),
      React.createElement(
        "span",
        { className: "ui-" + uiclass + "-info" },
        text
      ),
      children
    );
  };

  return NavItem;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = getCorePropDefaults({
  renderAs: "a",
  uirole: ROLE.ITEM,
  text: "",
  minimized: false
}), _temp);


export default NavItem;
